@@ -70,12 +70,12 @@ class PluginKateInsertCommand : public Kate::Plugin,
 
     uint configPages () const { return 1; }
     Kate::PluginConfigPage *configPage (uint , QWidget *w, const char *name=0);
-    QString configPageName(uint) const { return i18n("Insert Command"); };
+    QString configPageName(uint) const { return i18n("Insert Command"); }
     QString configPageFullName(uint) const {
-      return i18n("Configure Insert Command Plugin"); };
+      return i18n("Configure Insert Command Plugin"); }
     QPixmap configPagePixmap (uint /*number = 0*/,
                               int /*size = KIcon::SizeSmall*/) const
-                               { return 0L; };
+                               { return 0L; }
 
   private:
     void initConfigPage( InsertCommandConfigPage* );
@@ -144,15 +144,15 @@ class InsertCommandConfigPage : public Kate::PluginConfigPage
 
   public:
     InsertCommandConfigPage(QObject* parent = 0L, QWidget *parentWidget = 0L);
-    ~InsertCommandConfigPage() {};
+    ~InsertCommandConfigPage() {}
 
     /** Reimplemented from Kate::PluginConfigPage
      * just emits configPageApplyRequest( this ).
      */
     void apply();
 
-    void reset () { ; };
-    void defaults () { ; };
+    void reset () { ; }
+    void defaults () { ; }
 
   signals:
     /** Ask the plugin to set initial values */
