@@ -16,7 +16,7 @@
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
 
-$Id: kolourpicker.cpp 465369 2005-09-29 14:33:08Z mueller $
+$Id: kolourpicker.cpp 587667 2006-09-23 15:55:57Z kling $
 */
 
 #include <qfile.h>
@@ -53,7 +53,7 @@ extern "C"
 	{
 		KGlobal::locale()->insertCatalogue("kolourpicker");
 		return new KolourPicker(configFile, KPanelApplet::Normal,
-			KPanelApplet::About | KPanelApplet::Help,
+			KPanelApplet::About,
 			parent, "kolourpicker");
 	}
 }
@@ -119,11 +119,6 @@ void KolourPicker::about()
 	dlg.exec();
 }
 
-void KolourPicker::help()
-{
-	KMessageBox::information(0, i18n("Unimplemented help system."));
-}
-
 void KolourPicker::slotPick()
 {
 	m_picking = true;
