@@ -72,7 +72,7 @@ class MediaControlToolTip : public QToolTip
 {
 	public:
 		MediaControlToolTip(QWidget *widget, PlayerInterface *pl_obj) :
-			QToolTip(widget), mWidget(widget), mPlayer(pl_obj) {};
+			QToolTip(widget), mWidget(widget), mPlayer(pl_obj) {}
 
 	protected:
 		virtual void maybeTip(const QPoint &pt)
