@@ -58,10 +58,15 @@ ArkMenu::ArkMenu( KonqPopupMenu * popupmenu, const char *name, const QStringList
     KGlobal::locale()->insertCatalogue("ark_plugin");
 
     extMimeTypes();
-    m_list = popupmenu->fileItemList();
+    KFileItemList itemList = popupmenu->fileItemList();
+    for ( KFileItem *item = itemList.first(); item; item = itemList.next() )
+    {
+        m_urlList.append( item->url() );
+        m_urlStringList.append( item->url().url() );
+    }
     m_dir = popupmenu->url().url() + "/";
-    unsigned int itemCount = m_list.count();
-    KFileItemListIterator it( m_list );
+    unsigned int itemCount = m_urlList.count();
+    KFileItemListIterator it( itemList );
     KFileItem * item;
     bool hasArchives = false;
     bool hasOther = false;
@@ -84,15 +89,15 @@ ArkMenu::ArkMenu( KonqPopupMenu * popupmenu, const char *name, const QStringList
     QString ext;
     KActionMenu * actionMenu;
     KAction * action;
-    if ( hasOther &&  m_list.first()->name()!="." && popupmenu->protocolInfo().supportsWriting() )	// don't try to compress if we right click on a folder without files selected
+    if ( hasOther &&  itemList.first()->name()!="." && popupmenu->protocolInfo().supportsWriting() )	// don't try to compress if we right click on a folder without files selected
     {
         compMimeTypes();
         actionMenu = new KActionMenu( i18n( "Compress" ), "ark", actionCollection(), "ark_compress_menu"  );
         m_ext = m_conf->readEntry( "LastExtension", ".tar.gz" );
         if ( itemCount == 1 )
         {
-            item = m_list.first();
-            m_name = m_list.first()->name();
+            item = itemList.first();
+            m_name = itemList.first()->name();
             action = new KAction( i18n( "Compress as %1" ).arg( m_name + m_ext ), 0, this,
                                     SLOT( slotCompressAsDefault() ), actionCollection() );
         }
@@ -109,7 +114,7 @@ ArkMenu::ArkMenu( KonqPopupMenu * popupmenu, const char *name, const QStringList
 
 
         m_addToMenu = new KActionMenu( i18n( "Add To" ), actionCollection(), "arkaddtomnu" );
-        if ( m_list.first()->url().isLocalFile() )
+        if ( itemList.first()->url().isLocalFile() )
             actionMenu->insert( m_addToMenu );
 
         connect( m_compAsMenu->popupMenu(), SIGNAL( aboutToShow() ),
@@ -136,7 +141,7 @@ ArkMenu::ArkMenu( KonqPopupMenu * popupmenu, const char *name, const QStringList
             // stolen from arkwidget.cpp
             if ( itemCount == 1 )
             {
-                QString targetName = m_list.first()->name();
+                QString targetName = itemList.first()->name();
                 stripExtension( targetName );
                 action = new KAction( i18n( "Extract to %1" ).arg( targetName ), 0, this,
                                         SLOT( slotExtractToSubfolders() ), actionCollection() );
@@ -187,7 +192,7 @@ void ArkMenu::slotPrepareCompAsMenu()
         (*eit).remove( '*' );
         if ( *eit == ".tar.bz" )                   // tbz mimetype, has tar.bz as first entry :}
             *eit = ".tar.bz2";
-        if ( m_list.count() == 1 )
+        if ( m_urlList.count() == 1 )
         {
             action = new KAction( m_name + (*eit), 0, m_compAsMapper,
                     SLOT( map() ), actionCollection() );
@@ -231,7 +236,7 @@ void ArkMenu::slotPrepareAddToMenu()
     QCString actionName;
     QStringList::Iterator mit;
     KURL archive;
-    QDir dir( m_list.first()->url().directory() );
+    QDir dir( m_urlList.first().directory() );
     QStringList entries = dir.entryList();
     QStringList::Iterator uit = entries.begin();
     for ( ; uit != entries.end(); ++uit )
@@ -254,7 +259,7 @@ void ArkMenu::slotPrepareAddToMenu()
 
 void ArkMenu::compMimeTypes()
 {
-    unsigned int itemCount = m_list.count();
+    unsigned int itemCount = m_urlList.count();
 
     bool havegz = false;
     if ( !KStandardDirs::findExe( "gzip" ).isNull() && m_conf->readBoolEntry( "UseGz", true ) )
@@ -307,6 +312,13 @@ void ArkMenu::compMimeTypes()
     if ( !KStandardDirs::findExe( "rar" ).isNull() && m_conf->readBoolEntry( "UseRar", true ) )
         m_archiveMimeTypes << "application/x-rar" << "application/x-rar-compressed";
 
+    if ( !KStandardDirs::findExe( "7z" ).isNull() && m_conf->readBoolEntry( "Use7z", true ) )
+        m_archiveMimeTypes << "application/x-7z";
+    else if ( !KStandardDirs::findExe( "7za" ).isNull() && m_conf->readBoolEntry( "Use7za", true ) )
+        m_archiveMimeTypes << "application/x-7z";
+    else if ( !KStandardDirs::findExe( "7zr" ).isNull() && m_conf->readBoolEntry( "Use7zr", true ) )
+        m_archiveMimeTypes << "application/x-7z";
+
     if ( !KStandardDirs::findExe( "zoo" ).isNull() && m_conf->readBoolEntry( "UseZoo", false ) )
         m_archiveMimeTypes << "application/x-zoo";
 
@@ -367,6 +379,9 @@ void ArkMenu::extMimeTypes()
     if ( !KStandardDirs::findExe( "unrar" ).isNull() )
         m_extractMimeTypes << "application/x-rar" << "application/x-rar-compressed";
 
+    if ( !KStandardDirs::findExe( "7z" ).isNull() || !KStandardDirs::findExe( "7za" ).isNull() || !KStandardDirs::findExe( "7zr" ).isNull() )
+        m_extractMimeTypes << "application/x-7z";
+
     if ( !KStandardDirs::findExe( "zoo" ).isNull() )
         m_extractMimeTypes << "application/x-zoo";
 
@@ -401,21 +416,18 @@ void ArkMenu::slotCompressAs( int pos )
     QCString name;
     QString extension, mimeType;
     KURL target;
-    KFileItemListIterator it( m_list );
-    KFileItem * item;
-    QStringList filelist;
-    while (  ( item = it.current() ) != 0 )
-    {
-         ++it;
-         filelist.append( item->url().url() );
-    }
-    //if KMimeType returns .ZIP or .RAR. convert them to lowercase
+    QStringList filelist( m_urlStringList );
+
+    //if KMimeType returns .ZIP, .7Z or .RAR. convert them to lowercase
     if ( m_extensionList[ pos ].contains ( ".ZIP" ) )
          m_extensionList[ pos ] = ".zip";
 
     if ( m_extensionList[ pos ].contains ( ".RAR" ) )
          m_extensionList[ pos ] = ".rar";
 
+    if ( m_extensionList[ pos ].contains ( ".7Z" ) )
+         m_extensionList[ pos ] = ".7z";
+
     if ( filelist.count() == 1)
          target = filelist.first() + m_extensionList[ pos ];
     else
@@ -458,17 +470,10 @@ void ArkMenu::slotCompressAs( int pos )
 
 void ArkMenu::slotCompressAsDefault()
 {
-    KFileItemListIterator it( m_list );
-    KFileItem * item;
     KURL name;
-    QStringList filelist;
-    while (  ( item = it.current() ) != 0 )
-    {
-         ++it;
-         filelist.append( item->url().url() );
-    }
-    if ( filelist.count() == 1)
-         name = filelist.first() + m_ext;
+
+    if ( m_urlStringList.count() == 1)
+         name = m_urlStringList.first() + m_ext;
     else
     {
         name = m_dir + i18n("Archive") + m_ext;
@@ -479,7 +484,7 @@ void ArkMenu::slotCompressAsDefault()
             i++;
         }
     }
-    compressAs( filelist, name );
+    compressAs( m_urlStringList, name );
 }
 
 // make work for URLs
@@ -494,16 +499,10 @@ void ArkMenu::compressAs( const QStringList &name, const KURL & compressed )
 
 void ArkMenu::slotAddTo( int pos )
 {
-    QStringList args;
-    args << "--add-to";
-    KFileItemListIterator it( m_list );
-    KFileItem * item;
-    while (  ( item = it.current() ) != 0 )
-    {
-        ++it;
-        args << item->url().url();
-    }
-    KURL archive( m_list.first()->url() );
+    QStringList args( m_urlStringList );
+    args.prepend( "--add-to" );
+
+    KURL archive( m_urlStringList.first() );
     archive.setPath( archive.directory( false ) );
     archive.setFileName( m_archiveList[ pos ].fileName() );
 
@@ -513,63 +512,53 @@ void ArkMenu::slotAddTo( int pos )
 
 void ArkMenu::slotAdd()
 {
-    QStringList args;
-    args << "--add";
-    KFileItemListIterator it( m_list );
-    KFileItem * item;
-    while (  ( item = it.current() ) != 0 )
-    {
-        ++it;
-        args << item->url().url();
-    }
+    QStringList args( m_urlStringList );
+    args.prepend( "--add" );
+
     kapp->kdeinitExec( "ark", args );
 }
 
 void ArkMenu::slotExtractHere()
 {
-    QStringList args;
-    KFileItemListIterator it( m_list );
-    KFileItem * item;
-    while (  ( item = it.current() ) != 0 )
+    for ( QValueList<KURL>::ConstIterator it = m_urlList.constBegin();
+          it != m_urlList.constEnd();
+          ++it )
     {
-        args.clear();
-        ++it;
-        KURL targetDirectory = item->url();
+        QStringList args;
+        KURL targetDirectory = ( *it ).url();
         targetDirectory.setPath( targetDirectory.directory() );
-        args << "--extract-to"  << targetDirectory.url() << item->url().url();
+        args << "--extract-to"  << targetDirectory.url() << ( *it ).url();
         kapp->kdeinitExec( "ark", args );
     }
 }
 
 void ArkMenu::slotExtractToSubfolders()
 {
-    QStringList args;
-    QString dirName;
-    KURL targetDir;
-    KFileItemListIterator it( m_list );
-    KFileItem * item;
-    while (  ( item = it.current() ) != 0 )
+    for ( QStringList::ConstIterator it = m_urlStringList.constBegin();
+          it != m_urlStringList.constEnd();
+          ++it )
     {
-        args.clear();
-        ++it;
-        targetDir = item->url();
+        KURL targetDir;
+        QString dirName;
+        QStringList args;
+
+        targetDir = *it;
         dirName = targetDir.path();
         stripExtension( dirName );
         targetDir.setPath( dirName );
-        args << "--extract-to"  << targetDir.url() << item->url().url();
+        args << "--extract-to"  << targetDir.url() << *it;
         kapp->kdeinitExec( "ark", args );
     }
 }
 
 void ArkMenu::slotExtractTo()
 {
-    QStringList args;
-    KFileItemListIterator it( m_list );
-    KFileItem * item;
-    while (  ( item = it.current() ) != 0 )
+    for ( QStringList::ConstIterator it = m_urlStringList.constBegin();
+          it != m_urlStringList.constEnd();
+          ++it )
     {
-        ++it;
-        args << "--extract"  << item->url().url();
+        QStringList args;
+        args << "--extract" << *it;
         kapp->kdeinitExec( "ark", args );
     }
 }
