@@ -12,8 +12,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #include <unistd.h>
@@ -71,7 +71,7 @@ SessionManager::~SessionManager()
   m_self = 0;
 }
 
-QString SessionManager::generateKey (const KURL& url)
+QString SessionManager::generateKey (const KURL& url) const
 {
   QString key;
 
@@ -91,14 +91,16 @@ QString SessionManager::generateKey (const KURL& url)
   return key;
 }
 
-QStringList SessionManager::restore (const KURL& url)
+QStringList SessionManager::restoreMimeFilters (const KURL& url) const
 {
-  QString key = generateKey (url);
+  QString key(generateKey(url));
+  return m_filters[key];
+}
 
-  if (m_filters.contains(key))
-    return m_filters[key];
-  else
-    return QStringList ();
+QString SessionManager::restoreTypedFilter (const KURL& url) const
+{
+  QString key(generateKey(url));
+  return m_typedFilter[key];
 }
 
 void SessionManager::save (const KURL& url, const QStringList& filters)
@@ -107,6 +109,12 @@ void SessionManager::save (const KURL& url, const QStringList& filters)
   m_filters[key] = filters;
 }
 
+void SessionManager::save (const KURL& url, const QString& typedFilter)
+{
+  QString key = generateKey(url);
+  m_typedFilter[key] = typedFilter;
+}
+
 void SessionManager::saveSettings()
 {
   KConfig cfg ("dirfilterrc", false, false);
@@ -134,8 +142,10 @@ void SessionManager::loadSettings()
 
 
 DirFilterPlugin::DirFilterPlugin (QObject* parent, const char* name,
-                                  const QStringList &)
-                :KParts::Plugin (parent, name), m_pFilterMenu(0)
+                                  const QStringList&)
+                :KParts::Plugin (parent, name),
+                 m_pFilterMenu(0),
+                 m_searchWidget(0)
 {
   m_part = ::qt_cast<KonqDirPart*>(parent);
 
@@ -168,22 +178,22 @@ DirFilterPlugin::DirFilterPlugin (QObject* parent, const char* name,
 
   clear->setWhatsThis(i18n("Clear filter field<p>Clears the content of the filter field."));
 
-  QWidget *search = 0;
-  if ( m_part->scrollWidget()->inherits("QIconView") )
+  if ( ::qt_cast<KListView*>(m_part->scrollWidget()) )
   {
-    search = new KIconViewSearchLine(hbox);
-    static_cast<KIconViewSearchLine*>(search)->setIconView(static_cast<QIconView*>(m_part->scrollWidget()));
+    m_searchWidget = new KListViewSearchLine(hbox);
+    static_cast<KListViewSearchLine*>(m_searchWidget)->setListView(static_cast<KListView*>(m_part->scrollWidget()));
   }
-  else if ( m_part->scrollWidget()->inherits("KListView") )
+  else if ( ::qt_cast<QIconView*>(m_part->scrollWidget()) )
   {
-    search = new KListViewSearchLine(hbox);
-    static_cast<KListViewSearchLine*>(search)->setListView(static_cast<KListView*>(m_part->scrollWidget()));
+    m_searchWidget = new KIconViewSearchLine(hbox);
+    static_cast<KIconViewSearchLine*>(m_searchWidget)->setIconView(static_cast<QIconView*>(m_part->scrollWidget()));
   }
 
-  if ( search )
+
+  if ( m_searchWidget )
   {
-    QWhatsThis::add(search, i18n("Enter here a text which an item in the view must contain anywhere to be shown."));
-    connect(clear, SIGNAL(activated()), search, SLOT(clear()));
+    QWhatsThis::add(m_searchWidget, i18n("Enter here a text which an item in the view must contain anywhere to be shown."));
+    connect(clear, SIGNAL(activated()), m_searchWidget, SLOT(clear()));
   }
 
   KWidgetAction *filterAction = new KWidgetAction(hbox, i18n("Filter Field"),
@@ -205,9 +215,20 @@ void DirFilterPlugin::slotOpenURL ()
 
   if (m_pURL != url)
   {
+    //Clears the hidden list which is by now outdated...
+    if (m_searchWidget)
+    {
+      SessionManager::self()->save(m_pURL, m_searchWidget->text());
+      m_searchWidget->clear();
+
+      QString typedFilter(SessionManager::self()->restoreTypedFilter(url));
+      m_searchWidget->completionObject()->addItem(typedFilter);
+      m_searchWidget->setText(typedFilter);
+    }
+
     m_pURL = url;
     m_pMimeInfo.clear();
-    m_part->setMimeFilter (SessionManager::self()->restore(url));
+    m_part->setMimeFilter (SessionManager::self()->restoreMimeFilters(url));
   }
 }
 
@@ -228,7 +249,9 @@ void DirFilterPlugin::slotShowPopup()
   m_pFilterMenu->popupMenu()->clear();
   m_pFilterMenu->popupMenu()->insertTitle (i18n("Only Show Items of Type"));
 
-  for (MimeInfoIterator it = m_pMimeInfo.begin(); it != m_pMimeInfo.end() ; ++it)
+  MimeInfoIterator it = m_pMimeInfo.begin();
+  const MimeInfoIterator end = m_pMimeInfo.end();
+  for (; it != end ; ++it)
   {
     if (it.key().startsWith("inode"))
     {
@@ -262,7 +285,10 @@ void DirFilterPlugin::slotShowPopup()
   {
     m_pFilterMenu->popupMenu()->insertSeparator ();
 
-    for (QStringList::Iterator it = inodes.begin(); it != inodes.end(); ++it)
+    QStringList::Iterator it = inodes.begin();
+    QStringList::Iterator end = inodes.end();
+
+    for (; it != end; ++it)
     {
       if (!SessionManager::self()->showCount)
         label = m_pMimeInfo[(*it)].mimeComment;
@@ -371,19 +397,20 @@ void DirFilterPlugin::slotItemsAdded (const KFileItemList& list)
   for (KFileItemListIterator it (list); it.current (); ++it)
   {
     QString name = it.current()->name();
-    QString mimeType = it.current()->mimetype();
-
-    if (mimeType.isEmpty ())
+    KMimeType::Ptr mime = it.current()->mimeTypePtr(); // don't resolve mimetype if unknown
+    if (!mime)
       continue;
+    QString mimeType = mime->name();
 
     if (!m_pMimeInfo.contains (mimeType))
     {
+      MimeInfo& mimeInfo = m_pMimeInfo[mimeType];
       QStringList filters = m_part->mimeFilter ();
-      m_pMimeInfo[mimeType].useAsFilter = (!filters.isEmpty () &&
+      mimeInfo.useAsFilter = (!filters.isEmpty () &&
                                            filters.contains (mimeType));
-      m_pMimeInfo[mimeType].mimeComment = it.current ()->mimeComment();
-      m_pMimeInfo[mimeType].iconName = it.current ()->iconName();
-      m_pMimeInfo[mimeType].filenames.insert(name, false);
+      mimeInfo.mimeComment = mime->comment();
+      mimeInfo.iconName = mime->icon(KURL(), false);
+      mimeInfo.filenames.insert(name, false);
     }
     else
     {
@@ -433,8 +460,8 @@ void DirFilterPlugin::slotReset()
   KURL url = m_part->url();
 
   m_part->setMimeFilter (filters);
+  SessionManager::self()->save (url, filters);
   m_part->openURL (url);
-  SessionManager::self()->save (m_part->url(), filters);
 }
 
 void DirFilterPlugin::slotShowCount()
