@@ -202,8 +202,7 @@ void KImGalleryPlugin::createBody(QTextStream& stream, const QString& sourceDirN
 
 
             if (createThumb(imgName, sourceDirName, imgGalleryDir, imageFormat)) {
-                const QString imgNameFormat = imgName.left(imgName.findRev('.',-1));
-                const QString imgPath("thumbs/" + imgNameFormat + extension(imageFormat));
+                const QString imgPath("thumbs/" + imgName + extension(imageFormat));
                 stream << "<img src=\"" << imgPath << "\" width=\"" << m_imgWidth << "\" ";
                 stream << "height=\"" << m_imgHeight << "\" alt=\"" << imgPath << "\"/>";
                 m_progressDlg->setLabelText( i18n("Created thumbnail for: \n%1").arg(imgName) );
@@ -356,7 +355,7 @@ void KImGalleryPlugin::deleteCancelledGallery(const KURL& url, const QString& so
     // ..all the thumbnails ..
     for (uint i=0; i < imageDir.count(); i++) {
         const QString imgName = imageDir[i];
-        const QString imgNameFormat = imgName.left(imgName.findRev('.',-1)) + extension(imageFormat);
+        const QString imgNameFormat = imgName + extension(imageFormat);
         bool isRemoved = thumb_dir.remove(imgNameFormat);
         kdDebug(90170) << "removing: " << thumb_dir.path() << "/" << imgNameFormat << "; "<< isRemoved << endl;
     }
@@ -435,7 +434,7 @@ bool KImGalleryPlugin::createThumb( const QString& imgName, const QString& sourc
         KIO::NetAccess::copy(srcURL, destURL, static_cast<KParts::Part *>(parent())->widget());
     }
 
-    const QString imgNameFormat = imgName.left( imgName.findRev('.',-1) ) + extension(imageFormat);
+    const QString imgNameFormat = imgName + extension(imageFormat);
     const QString thumbDir = imgGalleryDir + QString::fromLatin1("/thumbs/");
     int extent = m_configDlg->getThumbnailSize();
 
