@@ -42,7 +42,6 @@ extern "C"
 #include <flowsystem.h>
 #include <kartsdispatcher.h>
 #include <kartsserver.h>
-#include <kmedia2.h>
 #include <kplayobjectfactory.h>
 #include <soundserver.h>
 
@@ -60,13 +59,13 @@ public:
 		, server()
 	{
 	}
-	
+
 	~EnginePrivate()
 	{
 		delete playobj;
 	}
 
-	KPlayObject *playobj;
+	KDE::PlayObject *playobj;
 	KArtsDispatcher dispatcher;
 	KArtsServer server;
 	KURL file;
@@ -100,25 +99,23 @@ bool Engine::reload(void)
 	delete d->playobj;
 	d->playobj = 0;
 
-	KPlayObjectFactory factory(d->server.server());
+	KDE::PlayObjectFactory factory(d->server.server());
 	d->playobj = factory.createPlayObject(d->file, true);
-	
-	return !d->playobj->object().isNull();
-}
 
-void Engine::getVideoId()
-{
-	if(!d->playobj) return;
+	needReload = false;
+
+	return !d->playobj->isNull();
 }
 
 void Engine::play()
 {
-	if(d->playobj && !d->playobj->object().isNull())
+	if(d->playobj)
 	{
 		switch(d->playobj->state())
 		{
 		case Arts::posIdle:
-			reload();
+			if(needReload)
+				reload();
 			d->playobj->play();
 			break;
 		case Arts::posPaused:
@@ -132,16 +129,16 @@ void Engine::play()
 
 void Engine::pause()
 {
-	if(d->playobj && !d->playobj->object().isNull())
+	if(d->playobj && !d->playobj->isNull())
 		d->playobj->pause();
 }
 
 void Engine::stop()
 {
-	if(d->playobj && !d->playobj->object().isNull())
+	if(d->playobj && !d->playobj->isNull())
 	{
 		d->playobj->halt();
-		seek(0);
+		needReload = true;
 	}
 }
 
@@ -153,14 +150,14 @@ void Engine::seek(unsigned long msec)
 	t.ms = (long) msec % 1000;
 	t.seconds = (long) ((long)msec - t.ms) / 1000;
 
-	if(d->playobj && !d->playobj->object().isNull())
+	if(d->playobj && !d->playobj->isNull())
 		d->playobj->seek(t);
 }
 
 // return position in milliseconds
 long Engine::position()
 {
-	if(!d->playobj || d->playobj->object().isNull()) return 0;
+	if(!d->playobj || d->playobj->isNull()) return 0;
 
 	Arts::poTime time(d->playobj->currentTime());
 	return (time.ms + (time.seconds*1000));
@@ -169,62 +166,42 @@ long Engine::position()
 // return track-length in milliseconds
 unsigned long Engine::length()
 {
-	if(!d->playobj || d->playobj->object().isNull()) return 0;
+	if(!d->playobj || d->playobj->isNull()) return 0;
 
 	Arts::poTime time(d->playobj->overallTime());
 	return (time.ms + (time.seconds*1000));
 }
 
-Engine::EngineState Engine::state()
+KMediaPlayer::Player::State Engine::state()
 {
-	if(!d->playobj || d->playobj->object().isNull()) return Empty;
+	if(!d->playobj || d->playobj->isNull()) return KMediaPlayer::Player::Empty;
 
 	switch(d->playobj->state())
 	{
 	case Arts::posIdle:
-		return Stop;
+		return KMediaPlayer::Player::Stop;
 		break;
 	case Arts::posPlaying:
-		return Play;
+		return KMediaPlayer::Player::Play;
 		break;
 	case Arts::posPaused:
-		return Pause;
+		return KMediaPlayer::Player::Pause;
+		break;
+	default:
+		return KMediaPlayer::Player::Stop;
 		break;
 	}
-	return Stop;
 }
 
-QString Engine::shellGlob(bool addAllFiles)
+bool Engine::seekable(void)
 {
-	QString full;
-	Arts::TraderQuery q;
-	std::vector<Arts::TraderOffer> *results = q.query();
-	QString str;
+	if(!d->playobj || d->playobj->isNull()) return false;
+	return d->playobj->capabilities() & Arts::capSeek;
+}
 
-	bool comma = false;
-
-	for(std::vector<Arts::TraderOffer>::iterator i = results->begin();
-	    i != results->end(); i++)
-	{
-		std::vector<string> *prop = (*i).getProperty("Extension");
-
-		for(vector<string>::iterator istr = prop->begin();
-		    istr != prop->end(); istr++)
-		{
-			if(!(*istr).length()) continue;
-			if(comma)
-				str += '\n';
-			comma = true;
-			str += i18n("*.%1|%2 Files").arg((*istr).c_str())
-			                                     .arg(QString((*istr).c_str()).upper());
-			full += QString("*.") + (*istr).c_str() + ' ';
-		}
-		delete prop;
-	}
-	delete results;
-	str = full + '|' + i18n("All Supported Files") + '\n' + str;
-	if(addAllFiles) str += "\n*|" + i18n("All Files");
-	return str;
+Arts::PlayObject Engine::playObject() const
+{
+	return d->playobj ? d->playobj->object() : Arts::PlayObject::null();
 }
 
 #include "engine.moc"
