@@ -106,7 +106,7 @@ ConfigDialog::ConfigDialog(QWidget *parent, const char *name) : QDialog(parent,
   servicemenus = new QCheckBox(i18n("Show service menus"), appearance_group);
   servicemenus->setChecked(config->readBoolEntry("ShowServicemenus", true));
   
-  showframe = new QCheckBox(i18n("Show Frame"), appearance_group);
+  showframe = new QCheckBox(i18n("Show frame"), appearance_group);
   showframe->setChecked(config->readBoolEntry("ShowFrame", true));
   
   QGroupBox *theme_group = new QGroupBox(2, Qt::Horizontal, i18n("Themes"), general);
