@@ -167,7 +167,7 @@ void KSig::writeConfig()
 bool KSig::queryClose()
 {
     if(changed) {
-	int saveChanges = KMessageBox::questionYesNoCancel(this, i18n("Do you want to save your changes before exiting?"));
+	int saveChanges = KMessageBox::questionYesNoCancel(this, i18n("Do you want to save your changes before exiting?"),QString::null,KStdGuiItem::save(),KStdGuiItem::discard());
 	if(saveChanges == KMessageBox::Cancel)
 	    return(false);
 	else if(saveChanges == KMessageBox::Yes)
