@@ -21,11 +21,13 @@
  */
 
 #include "userinterface.h"
+#include <klocale.h>
 
 extern "C"
 {
 	Plugin * create_plugin()
 	{
+		KGlobal::locale()->insertCatalogue("alsaplayerui");
 		return new AlsaPlayer;
 	}
 }
