@@ -14,7 +14,7 @@ RMS's novel that I'm supposed to put at the top of every story.  He's insane.
 #include <kwinmodule.h>
 #include <kiconloader.h>
 #include <math.h>
-#include <iostream.h>
+#include <iostream>
 
 #include <X11/Xlib.h>
 
